import { apply, filter, move, Rule, template, url, branchAndMerge, Tree, SchematicContext  } from '@angular-devkit/schematics';
import { chain, mergeWith } from '@angular-devkit/schematics';
import { normalize } from '@angular-devkit/core';
import { strings } from '@angular-devkit/core';
import { CrudOptions } from './schema';

import { parseName } from '../schematics-angular-utils/parse-name'; 
import { addDeclarationToNgModule, addProviderToNgModule } from '../utils/ng-module-utils';
import { findModuleFromOptions } from '../schematics-angular-utils/find-module';

function filterTemplates(options: CrudOptions): Rule {
  return filter(path => !path.match(/\.bak$/));
}




export default function (options: CrudOptions): Rule {
	
	return (host: Tree, context: SchematicContext) => {
		// TODO: Validate options and throw SchematicsException if validation fails
		
		
		
		options.path = options.path ? normalize(options.path) : options.path;
		options.module = options.module || findModuleFromOptions(host, options) || '';
		
		console.log(options);
		
		const parsedPath = parseName(options.path, options.name);
        options.name = parsedPath.name;
        options.path = parsedPath.path;
		
		const templateSource = apply(url('./files'), [
			filterTemplates(options),
			template({
			  ...strings,
			  ...options
			}),
			move(options.sourceDir)
		  ]);
		  console.log("\n");
		  console.log(parsedPath);
		const rule = chain([
			branchAndMerge(chain([
				mergeWith(templateSource),
				addDeclarationToNgModule(options, options.export),
				addProviderToNgModule(options, options.export)
			])),
		]);

      return rule(host, context);
	}
}
